//
//  ViewController.swift
//  SwiftMessagesSafeAreaInsets
//
//  Created by Jason Marr on 10/17/23.
//

import UIKit
import SwiftMessages

class ViewController: UIViewController {

    override func viewDidLoad() {
        super.viewDidLoad()
        view.backgroundColor = .systemBackground
        
        let showMessageButton = UIButton(type: .system)
        showMessageButton.translatesAutoresizingMaskIntoConstraints = false
        showMessageButton.setTitle("Show Message", for: .normal)
        showMessageButton.addTarget(self, action: #selector(showMessage), for: .touchUpInside)
        
        view.addSubview(showMessageButton)
        NSLayoutConstraint.activate([
            showMessageButton.centerXAnchor.constraint(equalTo: view.centerXAnchor),
            showMessageButton.centerYAnchor.constraint(equalTo: view.centerYAnchor)
        ])
    }
    
    @objc func showMessage() {
        let view = MessageView.viewFromNib(layout: .cardView)
        view.configureTheme(.info)
        
        view.configureContent(title: "Title", body: "Message")
        view.button?.isHidden = true
        
        if self.traitCollection.userInterfaceStyle == .light {
            view.overrideUserInterfaceStyle = .dark
        }
        
        var config = SwiftMessages.Config()
        config.presentationStyle = .bottom
        config.presentationContext = .viewController(self)

        SwiftMessages.show(config: config, view: view)
    }
}

